# Supported Device List #

----------
- Orange Pi Zero Plus2 H3
- Orange Pi Zero Plus2 H5
- Orange Pi Prime
- Orange Pi PC 2
- Orange Pi Zero
- Orange Pi PC Plus
- Orange Pi Plus2e
- Orange Pi Lite
- Orange Pi Plus2 and Plus
- Orange Pi PC 
- Orange Pi One
- Orange Pi2
- Raspberry Pi 2
- Raspberry Pi 3